# Security Policy

## Supported Versions

| Version | Supported                         |
| ------- | --------------------------------- |
| 2.0.x   | :x: (still in alpha/beta testing) |

## Reporting a Vulnerability

Please report vulnerabilities privately via GitHub:

https://github.com/moinwiki/moin/security

We will try to give you feedback and fix issues as soon as possible.
